@@ -6,6 +6,7 @@
 import hashlib
 import os
 import sys
+import typing as t
 from collections import OrderedDict
 from contextlib import contextmanager
 from datetime import datetime
@@ -15,56 +16,22 @@ try:
     import sqlite3
 except ImportError:
     try:
-        from pysqlite2 import dbapi2 as sqlite3
+        from pysqlite2 import dbapi2 as sqlite3  # type:ignore[no-redef]
     except ImportError:
-        sqlite3 = None
+        sqlite3 = None  # type:ignore[assignment]
 
 from base64 import encodebytes
 
 from jupyter_core.application import JupyterApp, base_flags
-from traitlets import (
-    Any,
-    Bool,
-    Bytes,
-    Enum,
-    Instance,
-    Integer,
-    TraitType,
-    Unicode,
-    default,
-    observe,
-)
+from traitlets import Any, Bool, Bytes, Callable, Enum, Instance, Integer, Unicode, default, observe
 from traitlets.config import LoggingConfigurable, MultipleInstanceError
 
 from . import NO_CONVERT, __version__, read, reads
 
-try:
-    # Python 3
-    algorithms = hashlib.algorithms_guaranteed
-    # shake algorithms in py36 are not compatible with hmac
-    # due to required length argument in digests
-    algorithms = [a for a in algorithms if not a.startswith("shake_")]
-except AttributeError:
-    algorithms = hashlib.algorithms
-
-
-# This has been added to traitlets, but is not released as of traitlets 4.3.1,
-# so a copy is included here for now.
-class Callable(TraitType):
-    """A trait which is callable.
-
-    Notes
-    -----
-    Classes are callable, as are instances
-    with a __call__() method."""
-
-    info_text = "a callable"
-
-    def validate(self, obj, value):
-        if callable(value):
-            return value
-        else:
-            self.error(obj, value)
+algorithms_set = hashlib.algorithms_guaranteed
+# The shake algorithms in are not compatible with hmac
+# due to required length argument in digests
+algorithms = [a for a in algorithms_set if not a.startswith("shake_")]
 
 
 class SignatureStore:
@@ -161,7 +128,9 @@ class SQLiteSignatureStore(SignatureStore, LoggingConfigurable):
             self.db.close()
 
     def _connect_db(self, db_file):
-        kwargs = dict(detect_types=sqlite3.PARSE_DECLTYPES | sqlite3.PARSE_COLNAMES)
+        kwargs: t.Dict[str, t.Any] = {
+            "detect_types": sqlite3.PARSE_DECLTYPES | sqlite3.PARSE_COLNAMES
+        }
         db = None
         try:
             db = sqlite3.connect(db_file, **kwargs)
@@ -389,12 +358,14 @@ class NotebookNotary(LoggingConfigurable):
         return os.path.join(self.data_dir, "nbsignatures.db")
 
     algorithm = Enum(
-        algorithms, default_value="sha256", help="""The hashing algorithm used to sign notebooks."""
+        algorithms,
+        default_value="sha256",
+        help="""The hashing algorithm used to sign notebooks.""",
     ).tag(config=True)
 
     @observe("algorithm")
     def _algorithm_changed(self, change):
-        self.digestmod = getattr(hashlib, change.new)
+        self.digestmod = getattr(hashlib, change["new"])
 
     digestmod = Any()
 
@@ -557,7 +528,7 @@ class NotebookNotary(LoggingConfigurable):
         return trusted
 
 
-trust_flags = {
+trust_flags: dict = {
     "reset": (
         {"TrustNotebookApp": {"reset": True}},
         """Delete the trusted notebook cache.
